@@ -569,6 +569,7 @@ main(int argc, char* argv[])
 			TIFFSetField(out, TIFFTAG_JPEGCOLORMODE, jpegcolormode);
 			break;
 		case COMPRESSION_LZW:
+		case COMPRESSION_ADOBE_DEFLATE:
 		case COMPRESSION_DEFLATE:
 			if (predictor != 0)
 				TIFFSetField(out, TIFFTAG_PREDICTOR, predictor);
@@ -882,7 +883,7 @@ processCompressOptions(char* opt)
 		char* cp = strchr(opt, ':');
 		if (cp)
 			predictor = atoi(cp+1);
-		compression = COMPRESSION_DEFLATE;
+		compression = COMPRESSION_ADOBE_DEFLATE;
 	} else
 		return (0);
 	return (1);
